@@ -9,11 +9,11 @@ testthat::test_that(desc="Correlation tests",
       
     testthat::expect_error(get_var_corr(test_data,comparison_var = "A"),
       "Found columns with only NAs. Please remove these first.",fixed=TRUE)
-    testthat::expect_error(get_var_corr(iris),"comparison_var is required.", fixed=TRUE)
+    testthat::expect_error(get_var_corr(yields),"comparison_var is required.", fixed=TRUE)
     
-    testthat::expect_warning( get_var_corr(iris,"Sepal.Length",
+    testthat::expect_warning( get_var_corr(yields,"weight",
                                            drop_columns = c("factor")),
-                             "Columns with classes in drop_columns have been discarded. Youcan disable this yourself by setting drop_columns to NULL.", fixed=TRUE)
+                  "Columns with classes in drop_columns have been discarded. You can disable this yourself by setting drop_columns to NULL.", fixed=TRUE)
   
     
     # Test that when a user changes the method, it actually works.
